MCD drain
Entreprise ( nom entreprise, adresse, téléphone )

- Le champ nom entreprise constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Entreprise.
- Les champs adresse et téléphone étaient déjà de simples attributs de l'entité Entreprise.

Étudiant ( num étudiant, nom, #num. stage u1, date signature, date?, note stage )

- Le champ num étudiant constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Étudiant.
- Le champ nom était déjà un simple attribut de l'entité Étudiant.
- Le champ num. stage est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle Attribuer à partir de l'entité Stage en perdant son caractère identifiant. Il obéit en outre à la contrainte d'unicité 1.
- Le champ date signature a migré à partir de l'association de dépendance fonctionnelle Attribuer.
- Le champ à saisie facultative date est un simple attribut. Il a migré par l'association de dépendance fonctionnelle Soutenir à partir de l'entité Date en perdant son caractère identifiant. Cependant, comme la table créée à partir de cette entité a été supprimée, il n'est pas considéré comme clé étrangère.
- Le champ note stage a migré à partir de l'association de dépendance fonctionnelle Soutenir.

Stage ( num. stage, sujet, #nom entreprise!, date proposition )

- Le champ num. stage constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Stage.
- Le champ sujet était déjà un simple attribut de l'entité Stage.
- Le champ à saisie obligatoire nom entreprise est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle Proposer à partir de l'entité Entreprise en perdant son caractère identifiant.
- Le champ date proposition a migré à partir de l'association de dépendance fonctionnelle Proposer.

NB. La table Date a été supprimée car elle était réduite à la clé primaire de son entité d'origine. Pour conserver de telles tables, préfixez d'un « + » la définition des entités d'origine.